@@ -10,7 +10,6 @@ seg.lm.fit <-function (y, XREG, Z, PSI, w, offs, opz, return.all.sol = FALSE)
         if (class(obj1)[1] == "try-error") obj1 <- try(lm.wfit(cbind(X, U1), y, w, offs), silent = TRUE)
         L1 <- if (class(obj1)[1] == "try-error") L0 + 10
         else sum(obj1$residuals^2 * w)
-        #r<-sum(obj1$residuals^2 * w)
         L1
     }
     est.k <- function(x1, y1, L0) {
@@ -199,7 +198,6 @@ seg.lm.fit <-function (y, XREG, Z, PSI, w, offs, opz, return.all.sol = FALSE)
         psi <- psi.old + gamma.c/beta.c
         #aggiusta la stima di psi..
         psi<- adj.psi(psi, rangeZ)
-        
         #browser()
         
         a<-optimize(search.min, c(0,1), psi=psi, psi.old=psi.old, X=XREG, y=y, w=w, offs=offs)
@@ -207,6 +205,7 @@ seg.lm.fit <-function (y, XREG, Z, PSI, w, offs, opz, return.all.sol = FALSE)
         L1<- a$objective
         #L1.k[length(L1.k) + 1] <- L1<- a$objective
         psi <- psi*use.k + psi.old* (1-use.k)
+        psi<- adj.psi(psi, limZ)
         if (!is.null(digits)) psi <- round(psi, digits)
         PSI <- matrix(rep(psi, rep(n, length(psi))), ncol = length(psi))
         U1 <- (Z - PSI) * (Z > PSI)
